Learn R Programming

kaps (version 1.0-0)

km.curve: Plot Kaplan-Meire survival curves

Description

Plot the Kaplan-Meire survival curves for terminal nodes or selected subgroups on a grapic device.

Usage

km.curve(object, 
	x.lab = c(0,24,48,72,96,120, 144, 168, 192, 216, 240), lwd = 1.5, ...)

Arguments

object
an object from kaps
x.lab
X labels specified as arguments
lwd
line width
...
other arguments for plot object. See plot for details.

Details

This function provides Kaplan-Meire survival curves with the estimated subgroups by kaps.

See Also

kaps