Rdocumentation
powered by
Learn R Programming
kaps (version 0.8.3)
km.curve: Plot Kaplan-Meire survival curves
Description
Plot the Kaplan-Meire survival curves for terminal nodes or subgroups on a grapic devide.
Usage
km.curve(object, x.lab = c(0,24,48,72,96,120, 144, 168, 192, 216, 240), ...)
Arguments
object
an object corresponding to "apss" or "Tree" S4 formulation classes.
x.lab
X labels specified as arguments
...
other arguments for plot object. See
plot
for details.
Details
This function provides Kaplan-Meire survival curves for terminal nodes or subgroups generated by
lrtree
.
See Also
lrtree